﻿using System;
using System.Collections.Generic;
using System.Xml.Linq;
using MinorShift.Emuera.Content;
using NTERA.Console;

namespace NTERA.Interop
{
	public static class HtmlParser
	{
		public static IEnumerable<IRenderItem> ParseHtml(string html)
		{
			return ParseHtml_Internal(XElement.Parse(html));
		}

		private static IEnumerable<IRenderItem> ParseHtml_Internal(XElement xmlNode)
		{
			List<IRenderItem> renderItems = new List<IRenderItem>();

			foreach (var node in xmlNode.Descendants())
			{
				switch (node.Name.LocalName)
				{
					case "p":
						renderItems.AddRange(ParseHtml_Internal(node));
						break;
					case "img":
						string src = node.Attribute("src")?.Value;

						if (src == null)
							throw new InvalidOperationException("HTML 'img' tag in script is missing 'src' attribute");

						var image = AppContents.GetContent<CroppedImage>(src);

						renderItems.Add(new ImageRenderItem(image.BaseImage.Bitmap, image.Rectangle));

						break;
					default:
						renderItems.Add(new TextRenderItem(node.ToString()));
						break;
				}
			}

			return renderItems;
		}
	}
}
