﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Imaging;

namespace NTERA.Console
{
	public class ImageRenderItem : BaseRenderItem
	{
		public Bitmap Image { get; set; }

		public ImageRenderItem(Bitmap bitmap)
		{
			Image = bitmap;
		}

		public ImageRenderItem(Bitmap original, Rectangle cropRectangle)
		{
			Image = new Bitmap(original.Width, cropRectangle.Height, PixelFormat.Format32bppArgb);

			using (Graphics g = Graphics.FromImage(Image))
			{
				g.DrawImage(original, new Rectangle(0, 0, original.Width, cropRectangle.Height), cropRectangle, GraphicsUnit.Pixel);
			}
		}

		public ImageRenderItem(string imagePath)
		{
			Image = new Bitmap(imagePath);
		}

		public override void Render(Graphics graphics, Rectangle renderArea, Point mousePointer)
		{
			graphics.DrawImage(Image, new Rectangle(0, renderArea.Y, Image.Width, renderArea.Height));
		}

		public static List<ImageRenderItem> CreateFromLargeBitmap(Bitmap original, int lineHeight)
		{
			List<ImageRenderItem> items = new List<ImageRenderItem>();

			int total = (int)Math.Ceiling(original.Height / (float)lineHeight);

			Rectangle destRect = new Rectangle(0, 0, original.Width, lineHeight);

			for (int i = 0; i < total; i++)
			{
				//Bitmap temp = new Bitmap(original.Width, lineHeight, PixelFormat.Format32bppArgb);

				//using (Graphics g = Graphics.FromImage(temp))
				//{
				//	g.DrawImage(original, destRect, new Rectangle(0, i * lineHeight, original.Width, lineHeight), GraphicsUnit.Pixel);
				//}

				items.Add(new ImageRenderItem(original, destRect));
			}

			return items;
		}
	}
}